package com.example.main;

import android.app.Activity;
import android.content.ContentValues;
import android.content.SharedPreferences;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.os.Bundle;
import android.view.KeyEvent;
import android.view.Menu;
import android.view.View;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemSelectedListener;
import android.widget.ArrayAdapter;
import android.widget.EditText;
import android.widget.ListView;
import android.widget.Spinner;
import android.widget.Toast;

import java.util.ArrayList;
import java.util.List;

public class BluetoothActivity extends Activity implements OnItemSelectedListener {

    public static final String DEFAULT_PROB = "DefaultProb";
    MySQLiteHelper helper;
    private SQLiteDatabase database;
    String deviceNames[] = new String[]{MySQLiteHelper.COLUMN_DEVICE_TITLE};
    BluetoothDeviceAdapter adapter; //should work here, even though it was initially intended for the contact activity
    private ListView bluetoothList;
    EditText editText;

    Spinner defaultProbSpinner, defaultPMISpinner;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_bluetooth_device);


        //Instantiate my editText
        editText = (EditText) findViewById(R.id.edittextNewDevice);
        //get the database to save the individual profiles to
        helper = new MySQLiteHelper(this);
        database = helper.getWritableDatabase();

        //get all of the time of day profiles
        List<DeleteLV> group = new ArrayList<DeleteLV>();
        group = getAllBluetoothDevices();


        //need to get the default probability for time of day
        SharedPreferences settings = getSharedPreferences(DEFAULT_PROB, 0);
        int defaultProb = settings.getInt("spinnerBluetoothDefaultProbabilty", 5);

        //populate the default probability spinner with 1 through 10
        defaultProbSpinner = (Spinner) findViewById(R.id.spinnerBluetoothDefaultProbabilty);

        ArrayAdapter<CharSequence> spinnerAdapter = ArrayAdapter.createFromResource(this, R.array.preference_spinner,
                android.R.layout.simple_spinner_dropdown_item);

        spinnerAdapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
        defaultProbSpinner.setAdapter(spinnerAdapter);
        defaultProbSpinner.setSelection(8);
        defaultProbSpinner.setOnItemSelectedListener(this);


        //populate the default default PMI Spinner
        defaultPMISpinner = (Spinner) findViewById(R.id.spinnerDefaultPMI);
        defaultPMISpinner.setSelection(0);


        //Use the ArrayAdapter to show the elements in the ListView
        adapter = new BluetoothDeviceAdapter(this, R.layout.group_row_layout, group);

        bluetoothList = (ListView) findViewById(R.id.bluetoothList);
        bluetoothList.setAdapter(adapter);

        editText.setOnKeyListener(new View.OnKeyListener() {
            @Override
            public boolean onKey(View v, int keyCode, KeyEvent event) {
                if (event.getAction() == KeyEvent.ACTION_DOWN)
                    if ((keyCode == KeyEvent.KEYCODE_DPAD_CENTER) ||
                            (keyCode == KeyEvent.KEYCODE_ENTER)) {
                        createDevice();
                        editText.setText("");

                        return true;
                    }
                return false;
            }
        });

    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.time_of_day, menu);
        return true;
    }

    public void onItemSelected(AdapterView<?> parent, View view,
                               int pos, long id) {
        SharedPreferences preferences = getSharedPreferences(DEFAULT_PROB, 0);
        SharedPreferences.Editor editor = preferences.edit();
        editor.putInt("spinnerBluetoothDefaultProbabilty", pos);
        editor.commit();

    }

    //handles when nothing has been selected
    public void onNothingSelected(AdapterView<?> parent) {
        //another callback interface
    }

    public List<DeleteLV> getAllBluetoothDevices() {
        List<DeleteLV> groups = new ArrayList<DeleteLV>();
        Cursor cursor = database.query(MySQLiteHelper.TABLE_BLUETOOTH_DEVICE, deviceNames, null, null, null, null, null);
        cursor.moveToFirst();
        while (!cursor.isAfterLast()) {
            groups.add(new DeleteLV(cursor.getString(0), R.id.deleteBtn));
            cursor.moveToNext();
        }
        cursor.close();
        return groups;
    }

    public void createDevice() {
        Boolean exists = false;

        DeleteLV newDevice = new DeleteLV(editText.getText().toString(), R.id.deleteBtn);

        //checks to make sure a group with this same name doesn't already exist
        //if there are no groups created yet, set exist to false
        if (adapter.getCount() == 0) {
            exists = false;
        } else {
            for (int i = 0; i < adapter.getCount(); i++) {
                if (adapter.getItem(i).title.equals(newDevice)) {
                    exists = true;
                    break;
                }
            }
        }
        if (!exists) {
            adapter.add(newDevice);
            insertDevice(newDevice.title);
        } else {
            Toast.makeText(getApplicationContext(), "This Device Already Exists", Toast.LENGTH_SHORT).show();
        }
        adapter.notifyDataSetChanged();
        


    }

    /**
     *
     * @param newDevice user input text not nullable
     */
    public void insertDevice(String newDevice) {
        ContentValues values = new ContentValues();
        values.put(MySQLiteHelper.COLUMN_DEVICE_TITLE, newDevice);
        //sets the default preference to 1
        values.put(MySQLiteHelper.COLUMN_DEVICE_PROB, Integer.parseInt(defaultProbSpinner.getSelectedItem().toString()) );
        //set the default call preference to ring
        values.put(MySQLiteHelper.COLUMN_DEVICE_INTERRUPTION_PREF, defaultPMISpinner.getSelectedItemPosition());
        values.put(MySQLiteHelper.COLUMN_DEVICE_LAST_DISCOVERED,0);
        //set all the days of the week to false
        database.insert(MySQLiteHelper.TABLE_BLUETOOTH_DEVICE, null,
                values);

    }


    @Override
    protected void onStop() {
        super.onStop();
        database.close();
    }

    @Override
    protected void onStart() {
        super.onStart();
        database = helper.getWritableDatabase();
    }


}
