package com.example.main;

import android.app.Activity;
import android.content.ContentValues;
import android.content.Intent;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.os.Bundle;
import android.telephony.PhoneNumberUtils;
import android.view.View;
import android.widget.Button;
import android.widget.Toast;

import com.example.main.com.example.main.utility.MatrixRow;
import com.example.main.com.example.main.utility.ProbabilityUtil;

import java.util.ArrayList;
import java.util.Calendar;


public class FeedbackActivity extends Activity {
    private MySQLiteHelper helper;
    private SQLiteDatabase database;

    @Override
    protected void onCreate(Bundle savedInstanceState) {

        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_feedback);
        final Button gdInterruptionBtn = (Button) findViewById(R.id.goodinterruptionbtn);
        final Button bdInterruptionBtn = (Button) findViewById(R.id.badinterruptionbtn);

        helper = new MySQLiteHelper(getApplicationContext());
        gdInterruptionBtn.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                saveFeedback("0");
            }
        });
        bdInterruptionBtn.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                //Store feedback for future
                saveFeedback("1");
            }
        });

    }

    private void saveFeedback(String feedbackVal) {
        // Store feedback for future use
        //Fetch phone number from the intent
        Intent feedbackIntent = getIntent();
        String incomingNumber = feedbackIntent.getStringExtra("incomingNumber");
        //Fetch caller group number the caller belongs to from contact group  table
        database = helper.getReadableDatabase();

        String phoneNumber = PhoneNumberUtils.formatNumber(incomingNumber);
        //Cursor result= database.rawQuery("select " +helper.COLUMN_CONTACTGROUP+ " from " + helper.TABLE_CONTACTS + " where " +helper.COLUMN_CONTACTPHONE+ "="+incomingNumber ,null);
        Cursor result = database.query(MySQLiteHelper.TABLE_CONTACTS, null, null, null, null, null, null);
        if (result == null)
            return; //Write code here to handle if phone number is not in any group
        // Now insert into feedback table

        String groupId=null;
        while(result.moveToNext()){

            String contactNo = PhoneNumberUtils.formatNumber(result.getString(result.getColumnIndex(MySQLiteHelper.COLUMN_CONTACTPHONE)));

            if(contactNo.compareToIgnoreCase(phoneNumber)==0){
                groupId = result.getString(result.getColumnIndex(helper.COLUMN_CONTACTGROUP));
                break;
            }
        }
        result.close();

        if (groupId!=null) {

            database = helper.getWritableDatabase();
            ContentValues values = new ContentValues();

            values.put(MySQLiteHelper.COLUMN_FEEDBACK_GROUPID, groupId);
            values.put(MySQLiteHelper.COLUMN_FEEDBACKVAL, feedbackVal); //Good interuptions will have a value 0 bad interruptions are 1
            database.insert(MySQLiteHelper.TABLE_FEEDBACK, null, values);

            Toast.makeText(getApplicationContext(), "Thanks for your feedback!", Toast.LENGTH_LONG).show();

            updateMatrix(groupId);
            FeedbackActivity.this.finish();
        }


        //;
    }

    private void updateMatrix(String matrixGroupId) {
        // todo : Now the next thing to do is to divide number of bad interruptions by 50 and then store that value to Matrix table for appropriate caller group and time of day
        // So that we get the probability of bad interruption for a specific caller group and time of day
        database = helper.getReadableDatabase();
        Cursor result = database.query(MySQLiteHelper.TABLE_FEEDBACK, null, MySQLiteHelper.COLUMN_FEEDBACK_GROUPID + "=?", new String[]{matrixGroupId}, null, null, MySQLiteHelper.COLUMN_FEEDBACKID + " desc");
        // TODO: 7/14/2016 if there are more than 49 entries in feedback table for a group fetch last 50 entries
        int numberOfRows = 0;
        int numberOf1Val = 0;

        while (result.moveToNext()) {
            numberOfRows++;

            int feeedback = Integer.parseInt(result.getString(result.getColumnIndex(MySQLiteHelper.COLUMN_FEEDBACKVAL)));
            if (feeedback == 1) {
                numberOf1Val++;
            }

            if (numberOf1Val == 51)
                break;
        }
        result.close();

        if (numberOf1Val < 2)
            return;

        Calendar cal = Calendar.getInstance();
        String[] todItems = new String[]{MySQLiteHelper.COLUMN_TODID, MySQLiteHelper.COLUMN_TODINTERRUPTIONPREF, MySQLiteHelper.COLUMN_TODPROB};
        //System.out.println(getDayOfWeek(cal.get(Calendar.DAY_OF_WEEK)));
        int specialTimeFormat = cal.get(Calendar.HOUR_OF_DAY) * 60 + cal.get(Calendar.MINUTE);
        Cursor todCursor = database.query(MySQLiteHelper.TABLE_TOD_PROFILE, todItems, getDayOfWeek(cal.get(Calendar.DAY_OF_WEEK)) + " = 1"
                + " and " + MySQLiteHelper.COLUMN_STARTTIME + " < '" + specialTimeFormat + "' and " + MySQLiteHelper.COLUMN_ENDTIME
                + " > '" + specialTimeFormat + "'", null, null, null, null);
        //presuming that all 7 days are activated in the TOD creation

        String todID = null;
        String todProb = null;

        todCursor.moveToFirst();
        if (todCursor.getCount() > 0) {
            //System.out.println("I got here from time of day");
            todID = todCursor.getString(todCursor.getColumnIndex(MySQLiteHelper.COLUMN_TODID));
            todProb = todCursor.getString(todCursor.getColumnIndex(MySQLiteHelper.COLUMN_TODPROB));
        }
        todCursor.close();

        // TODO: 7/14/2016 divide summation of COLUMN_FEEDBACKVAL of last 50 entries by 50

        double matrixProb = numberOf1Val / numberOfRows;

        // TODO: 7/14/2016 insert above probability into TABLE_MATRIX where COLUMN_MATRIX_TOD_ID represents current time and COLUMN_MATRIX_GROUP_ID = groupid

        if (todID != null && matrixGroupId != null) {
            ArrayList<MatrixRow> matrixRows = ProbabilityUtil.getFullMatrix(getApplicationContext());

            for (MatrixRow row : matrixRows) {
                if (row.getMatrix_group_id().compareToIgnoreCase(matrixGroupId) == 0 && row.getMatrix_tod_id().compareToIgnoreCase(todID) == 0) {

                    String matrixId = row.getMatrix_id();
                    ProbabilityUtil.updateProbabilityMatrixValue(getApplicationContext(), todID, matrixGroupId, String.valueOf(matrixProb), matrixId);
                    break;
                }

            }
        }


    }

    public String getDayOfWeek(int day) {
        switch (day) {
            case 1:
                return MySQLiteHelper.COLUMN_SUNDAY;
            case 2:
                return MySQLiteHelper.COLUMN_MONDAY;
            case 3:
                return MySQLiteHelper.COLUMN_TUESDAY;
            case 4:
                return MySQLiteHelper.COLUMN_WEDNESDAY;
            case 5:
                return MySQLiteHelper.COLUMN_THURSDAY;
            case 6:
                return MySQLiteHelper.COLUMN_FRIDAY;
            case 7:
                return MySQLiteHelper.COLUMN_SATURDAY;
            default:
                return null;
        }
    }


}
