package com.example.main;

import android.app.Activity;
import android.content.Context;
import android.text.Editable;
import android.text.TextWatcher;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.EditText;
import android.widget.TextView;

import com.example.main.com.example.main.utility.MatrixRow;
import com.example.main.com.example.main.utility.ProbabilityUtil;

import java.util.List;

/**
 * Created by Audwit on 5/16/16.
 */
public class MatrixAdapter extends BaseAdapter {

    private List<MatrixRow> matrixRows;
    private Context context;

    private int editingPosition = 0;

    public MatrixAdapter(List<MatrixRow> matrixRows, Context context) {
        this.matrixRows = matrixRows;
        this.context = context;
    }

    @Override
    public int getCount() {
        return matrixRows.size();
    }

    @Override
    public MatrixRow getItem(int position) {
        return matrixRows.get(position);
    }

    @Override
    public long getItemId(int position) {
        return position;
    }


    public void saveToDB(){

        for (MatrixRow row:matrixRows) {

            ProbabilityUtil.updateProbabilityMatrixValue(context,row.getMatrix_tod_id(),row.getMatrix_group_id(),row.getMatrix_value(),row.getMatrix_id());
        }

    }


    @Override
    public View getView(final int position, View convertView, ViewGroup parent) {

        ViewHolder holder = null;

        LayoutInflater mInflater = (LayoutInflater) context.getSystemService(Activity.LAYOUT_INFLATER_SERVICE);
        if (convertView == null) {
            convertView = mInflater.inflate(R.layout.matrix_row_layout, parent,false);
            holder = new ViewHolder();
            holder.rowTitle = (TextView) convertView.findViewById(R.id.matrix_row_label);
            holder.rowValue = (EditText) convertView.findViewById(R.id.matrix_row_value);

            convertView.setTag(holder);
        }
        else {
            holder = (ViewHolder) convertView.getTag();
        }


        MatrixRow row = matrixRows.get(position);


        holder.rowValue.removeTextChangedListener(textWatcher);

        holder.rowTitle.setText("Enter PLI for "+row.getMatrix_group_title()+" during "+row.getMatrix_tod_title());
        holder.rowValue.setText(row.getMatrix_value());

        holder.rowValue.setOnFocusChangeListener(new View.OnFocusChangeListener() {
            public void onFocusChange(View v, boolean hasFocus) {
                if (hasFocus)
                    editingPosition = position;
            }
        });

        holder.rowValue.addTextChangedListener(textWatcher);

        return convertView;
    }


    private TextWatcher textWatcher = new TextWatcher() {

        //private int editingPosition;
        @Override
        public void beforeTextChanged(CharSequence s, int start, int count, int after) {

        }

        @Override
        public void onTextChanged(CharSequence s, int start, int before, int count) {
        }

        @Override
        public void afterTextChanged(Editable s) {

            MatrixRow editedRow = matrixRows.get(editingPosition);
            String newVal = s.toString();

            editedRow.setMatrix_value(newVal);
            matrixRows.set(editingPosition,editedRow);

        }

        public TextWatcher setRowPosition(int editingPosition) {
           editingPosition = editingPosition;
            return this;
        }
    };


    /*private view holder class*/
    static class ViewHolder {

        TextView rowTitle;
        EditText rowValue;
    }
}
