package com.example.main.com.example.main.utility;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.util.Log;

import com.example.main.MySQLiteHelper;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;

public class ProbabilityUtil {

    private static MySQLiteHelper helper;
    private static SQLiteDatabase database;

    private final double default_Matrix_probability = 0.5;


    private static void insertProbabilityTemplate(Context context, String todID, String groupID, String todTitle, String groupTitle) {
        helper = new MySQLiteHelper(context);
        database = helper.getWritableDatabase();
        ContentValues values = new ContentValues();
        values.put(MySQLiteHelper.COLUMN_MATRIX_TOD_ID, todID);
        values.put(MySQLiteHelper.COLUMN_MATRIX_GROUP_ID, groupID);
        values.put(MySQLiteHelper.COLUMN_MATRIX_TOD_TITLE, todTitle);
        values.put(MySQLiteHelper.COLUMN_MATRIX_GROUP_TITLE, groupTitle);
        values.put(MySQLiteHelper.COLUMN_MATRIX_VALUE, .5);
        values.put(MySQLiteHelper.COLUMN_MATRIX_UPDATED_TIME, System.currentTimeMillis());
        long success = database.insert(MySQLiteHelper.TABLE_MATRIX, null,
                values);
        Log.d("Audwit", "insertProbabilityTemplate ===== " + success);

    }

    public static void removeProbabilityTemplateByTOD(Context context, String todID) {
        helper = new MySQLiteHelper(context);
        database = helper.getWritableDatabase();
        // remove from TABLE_MATRIX with COLUMN_MATRIX_TOD_ID = todID
        database.delete(MySQLiteHelper.TABLE_MATRIX, MySQLiteHelper.COLUMN_MATRIX_TOD_ID + "=?", new String[]{todID});

    }

    public static void removeProbabilityTemplateByGroup(String groupId) {
        database = helper.getWritableDatabase();
        // remove from TABLE_MATRIX with COLUMN_MATRIX_GROUP_ID = groupId
        database.delete(MySQLiteHelper.TABLE_MATRIX, MySQLiteHelper.COLUMN_MATRIX_GROUP_ID + "=?", new String[]{groupId});
    }

    public static void createProbabilityTemplateForTOD(Context context, String todID, String todTitle) {

        helper = new MySQLiteHelper(context);
        database = helper.getReadableDatabase();
        ArrayList<String> groupIds = new ArrayList<String>();
        ArrayList<String> groupNames = new ArrayList<String>();
        // fetch all COLUMN_GROUPID from TABLE_GROUPS into groupIds and corresponding COLUMN_GROUPNAME into groupNames

        //Cursor result = database.rawQuery("Select group_id, group_name from groups",null);
        Cursor result = database.query(MySQLiteHelper.TABLE_GROUPS, new String[]{MySQLiteHelper.COLUMN_GROUPID, MySQLiteHelper.COLUMN_GROUPNAME}, null, null, null, null, null);

        while (result.moveToNext()) {
            groupIds.add(result.getString(0));
            groupNames.add(result.getString(1));
        }
        result.close();

        if (!groupIds.isEmpty()) {

            for (int i = 0; i < groupIds.size(); i++) {
                String groupId = groupIds.get(i).toString();
                String groupName = groupNames.get(i).toString();

                insertProbabilityTemplate(context, todID, groupId, todTitle, groupName);
            }

        }

    }

    public static void createProbabilityTemplateForGroup(Context context, String groupId, String groupName) {
        helper = new MySQLiteHelper(context);
        database = helper.getReadableDatabase();

        ArrayList<String> todIds = new ArrayList<String>();
        ArrayList<String> todTitles = new ArrayList<String>();
        // fetch all COLUMN_TODID from TABLE_TOD_PROFILE into todIds and corresponding COLUMN_TODTITLE into todTitles
        //Cursor result = database.rawQuery("Select tod_id, tod_title from timeOfDay",null);
        Cursor result = database.query(MySQLiteHelper.TABLE_TOD_PROFILE, new String[]{MySQLiteHelper.COLUMN_TODID, MySQLiteHelper.COLUMN_TODTITLE}, null, null, null, null, null);
        //result.moveToFirst();
        while (result.moveToNext()) {
            todIds.add(result.getString(0));
            todTitles.add(result.getString(1));
        }

        result.close();

        if (!todIds.isEmpty()) {

            /// if there is any TOD
            for (int i = 0; i < todIds.size(); i++) {
                String todID = todIds.get(i).toString();
                String todTitle = todTitles.get(i).toString();

                insertProbabilityTemplate(context, todID, groupId, todTitle, groupName);
            }

        }

    }

    public static void updateProbabilityMatrixValue(Context context, String todID, String groupID, String value, String matrixId) {
        helper = new MySQLiteHelper(context);

        database = helper.getWritableDatabase();
        Calendar c = Calendar.getInstance();
        System.out.println("Current time =&gt; " + c.getTime());

        SimpleDateFormat df = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        String formattedDateTime = df.format(c.getTime());
        // Now formattedDate have current date/time
        //Toast.makeText(this, formattedDateTIme, Toast.LENGTH_SHORT).show();

        ContentValues contentValues = new ContentValues();
        contentValues.put(MySQLiteHelper.COLUMN_MATRIX_VALUE, value);
        contentValues.put(MySQLiteHelper.COLUMN_MATRIX_UPDATED_TIME, formattedDateTime);
        if (matrixId != null && !matrixId.isEmpty()) {
            int numberOfRowsAffected = database.update(MySQLiteHelper.TABLE_MATRIX, contentValues, MySQLiteHelper.COLUMN_MATRIX_ID + " = ?", new String[]{matrixId});
            Log.d("Audwit", "numberOfRowsAffected ====" + numberOfRowsAffected);
        }


    }

    public static ArrayList<MatrixRow> getFullMatrix(Context context) {
        helper = new MySQLiteHelper(context);
        database = helper.getReadableDatabase();
        ArrayList<MatrixRow> matrixRows = new ArrayList<MatrixRow>();

        // fetch select * from TABLE_MATRIX group by COLUMN_MATRIX_GROUP_ID
        //Cursor result= database.rawQuery("select * from matrix group by matrix_group_id",null);
        Cursor result = database.query(MySQLiteHelper.TABLE_MATRIX, null, null, null, null, null, null);
        // create an object of MatrixRow from cursor by loop and insert into matrixRows list
        while (result.moveToNext()) {
            MatrixRow matrixRow = new MatrixRow();
            matrixRow.setMatrix_id(result.getString(result.getColumnIndex(MySQLiteHelper.COLUMN_MATRIX_ID)));
            matrixRow.setMatrix_tod_id(result.getString(result.getColumnIndex(MySQLiteHelper.COLUMN_MATRIX_TOD_ID)));
            matrixRow.setMatrix_tod_title(result.getString(result.getColumnIndex(MySQLiteHelper.COLUMN_MATRIX_TOD_TITLE)));
            matrixRow.setMatrix_group_id(result.getString(result.getColumnIndex(MySQLiteHelper.COLUMN_MATRIX_GROUP_ID)));
            matrixRow.setMatrix_group_title(result.getString(result.getColumnIndex(MySQLiteHelper.COLUMN_MATRIX_GROUP_TITLE)));
            matrixRow.setMatrix_value(result.getString(result.getColumnIndex(MySQLiteHelper.COLUMN_MATRIX_VALUE)));
            matrixRow.setMatrix_updated_time(result.getString(result.getColumnIndex(MySQLiteHelper.COLUMN_MATRIX_UPDATED_TIME)));

            matrixRows.add(matrixRow);
        }
        return matrixRows;

    }

}
